@@ -1,5 +1,6 @@
 from SpatialCluster.methods.DMoN import IncrementalCOOMatrix, convert_scipy_sparse_to_sparse_tensor, build_dmon, normalize_graph
 from SpatialCluster.methods.functions import get_areas
+from SpatialCluster.preprocess import adjacencyMatrix
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
@@ -45,7 +46,8 @@ def DMoN_Clustering(features_X, features_position, r_max = 0.00034, n_clusters =
     X = np.asmatrix(X) # feature matrix
 
     # --------------------------------------------------------------------------
-    
+    points = list(zip(features_position.lon, features_position.lat))
+    """
     data = list(zip(features_position.lon, features_position.lat))
     tree = spatial.KDTree(data = data, leafsize = 10)
     points = list(zip(features_position.lon, features_position.lat))
@@ -67,6 +69,8 @@ def DMoN_Clustering(features_X, features_position, r_max = 0.00034, n_clusters =
 
     A = mat.tocoo() # adjacency matrix
     A = A.tocsr()
+    """
+    A = adjacencyMatrix(features_position)
     n_nodes = A.shape[0]
     feature_size = X.shape[1]
 
